summaryrefslogtreecommitdiff
path: root/plugins/modules/vyos_route_maps.py
diff options
context:
space:
mode:
authorSagar Paul <sagpaul@redhat.com>2021-06-22 23:55:12 +0530
committerGitHub <noreply@github.com>2021-06-22 18:25:12 +0000
commita8e806d61fc1e4fd88592bee7e501fbe259cca99 (patch)
treece0a89c73c8e14c173c37dd9e720e94ad2576441 /plugins/modules/vyos_route_maps.py
parenteb46eb529a8bcfaeb5a7e736550d7cfb612b02d7 (diff)
downloadvyos.vyos-a8e806d61fc1e4fd88592bee7e501fbe259cca99.tar.gz
vyos.vyos-a8e806d61fc1e4fd88592bee7e501fbe259cca99.zip
Spelling glitch fix on doc (#168)
Spelling glitch fix on doc Reviewed-by: https://github.com/apps/ansible-zuul
Diffstat (limited to 'plugins/modules/vyos_route_maps.py')
-rw-r--r--plugins/modules/vyos_route_maps.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/modules/vyos_route_maps.py b/plugins/modules/vyos_route_maps.py
index bca8383d..c8e7352b 100644
--- a/plugins/modules/vyos_route_maps.py
+++ b/plugins/modules/vyos_route_maps.py
@@ -91,7 +91,7 @@ options:
description: Delete BGP communities matching the community-list.
community:
type: dict
- description: Border Gateway Protocl (BGP) community attribute.
+ description: Border Gateway Protocol (BGP) community attribute.
suboptions:
value:
type: str
@@ -135,7 +135,7 @@ options:
choices: [ "egp", "igp", "incomplete" ]
originator_id:
type: str
- description: Border Gateway Protocol (BGP) originator ID attribute. Orignator IP address.
+ description: Border Gateway Protocol (BGP) originator ID attribute. Originator IP address.
src:
type: str
description: Source address for route. Example <x.x.x.x> IP address.
@@ -264,7 +264,7 @@ EXAMPLES = """
# vyos@vyos:~$ show configuration commands | match "set policy route-map"
# vyos@vyos:~$
- - name: Merge the provided configuration with the exisiting running configuration
+ - name: Merge the provided configuration with the existing running configuration
register: result
vyos.vyos.vyos_route_maps: &id001
config:
@@ -394,7 +394,7 @@ EXAMPLES = """
# set policy route-map test3 rule 1 set tag '5'
# set policy route-map test3 rule 1 set weight '4'
#
# - name: Replace the provided configuration with the exisiting running configuration
# register: result
# vyos.vyos.vyos_route_maps: &id001
# config:
@@ -394,7 +394,7 @@ EXAMPLES = """
# set policy route-map test3 rule 1 set weight '4'
#
-# - name: Replace the provided configuration with the exisiting running configuration
+# - name: Replace the provided configuration with the existing running configuration
# register: result
# vyos.vyos.vyos_route_maps: &id001